==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+76"/>
        <source>First line, arc or circle</source>
        <translation>Prima linea, arco, cerchio</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Seconda linea, arco, cerchio</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Scegli soluzione</translation>
    </message>
    <message>
        <location line="+97"/>
        <location line="+94"/>
        <source>No solution</source>
        <translation>Nessuna soluzione</translation>
    </message>
    <message>
        <location line="-44"/>
        <source>Invalid radius</source>
        <translation>Raggio valido</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Raggio:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 &amp;tangenti e raggio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Disegnare un cerchio tangente a due entità con un raggio</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+77"/>
        <source>First line, arc or circle</source>
        <translation>Prima linea, arco, cerchio</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Seconda linea, arco, cerchio</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Scegli soluzione</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>No solution</source>
        <translation>Nessuna soluzione</translation>
    </message>
    <message>
        <source>Invalid radius</source>
        <translation type="vanished">Raggio valido</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Raggio:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 &amp;tangenti e raggio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Disegnare un cerchio tangente a due entità con un raggio</translation>
    </message>
</context>
</TS>
